<?php
/**
 * CedCommerce
  *
  * NOTICE OF LICENSE
  *
  * This source file is subject to the End User License Agreement (EULA)
  * that is bundled with this package in the file LICENSE.txt.
  * It is also available through the world-wide-web at this URL:
  * http://cedcommerce.com/license-agreement.txt
  *
  * @category  Ced
  * @package   Ced_LayBuy
  * @author    CedCommerce Core Team <connect@cedcommerce.com >
  * @copyright Copyright CEDCOMMERCE (http://cedcommerce.com/)
  * @license   https://cedcommerce.com/license-agreement.txt
  */

namespace Ced\LayBuy\Block\Adminhtml\Orders;

class Grid extends \Magento\Backend\Block\Widget\Grid\Extended
{

    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Backend\Helper\Data $backendHelper,
        \Magento\Sales\Model\ResourceModel\Order\Grid\CollectionFactory $orderCollection,
        \Magento\Sales\Model\Order\Config $orderConfig,
        \Ced\LayBuy\Helper\Data $laybuyHelper,
        \Magento\Store\Model\StoreManager $storeManager,
        array $data = []
    ) {
        
        $this->storeManager = $storeManager;
        $this->orderCollection = $orderCollection;
        $this->laybuyHelper = $laybuyHelper;
        $this->orderConfig = $orderConfig;
        parent::__construct($context, $backendHelper, $data);
    }
 
    /**
     * @return void
     */
    protected function _construct()
    {
        parent::_construct();
        $this->setId('sales_laybuy_order_grid');
        $this->setDefaultSort('id');
        $this->setDefaultDir('DESC');
        $this->setSaveParametersInSession(true);
        $this->setUseAjax(true);
        $this->setVarNameFilter('post_filter');
    }
 
    /**
     * @return $this
     */
    protected function _prepareCollection()
    {
	    $allIds = $this->laybuyHelper->getPaidOrders();
		$collection = $this->orderCollection->create()->addFieldToFilter('entity_id',['in'=>$allIds]);

		$this->setCollection($collection);
		return parent::_prepareCollection();

    }
 

    /**
     * @return $this
     * @throws \Exception
     */
    protected function _prepareColumns()
    {
       $this->addColumn(
            'real_order_id',
            [
                'header' => __('Order #'),
                'type' => 'text',
                'index' => 'increment_id',
                
            ]
        );
        
        if (!$this->storeManager->isSingleStoreMode()) {
            $this->addColumn('store_id', [
                'header'    => __('Purchased From (Store)'),
                'index'     => 'store_id',
                'type'      => 'store',
                'store_view'=> true,
                'display_deleted' => true,
            ]);
        }

        $this->addColumn('created_at', [
            'header' => __('Purchased On'),
            'index' => 'created_at',
            'type' => 'datetime',
            'width' => '100px',
        ]);

        $this->addColumn('billing_name', [
            'header' => __('Bill to Name'),
            'index' => 'billing_name',
        ]);

        $this->addColumn('shipping_name', [
            'header' => __('Ship to Name'),
            'index' => 'shipping_name',
        ]);

        $this->addColumn('base_grand_total', [
            'header' => __('G.T. (Base)'),
            'index' => 'base_grand_total',
            'type'  => 'currency',
            'currency' => 'base_currency_code',
        ]);

        $this->addColumn('grand_total', [
            'header' => __('G.T. (Purchased)'),
            'index' => 'grand_total',
            'type'  => 'currency',
            'currency' => 'order_currency_code',
        ]);

        $this->addColumn('status', [
            'header' => __('Status'),
            'index' => 'status',
            'type'  => 'options',
            'width' => '70px',
            'options' => $this->orderConfig->getStatuses(),
        ]);

      
            $this->addColumn('action',
                [
                    'header'    => __('Action'),
                    'width'     => '50px',
                    'type'      => 'action',
                    'getter'     => 'getId',
                    'actions'   => [
                        [
                            'caption' => __('View'),
                            'url'     => ['base'=>'sales/order/view'],
                            'field'   => 'order_id'
                        ]
                    ],
                    'filter'    => false,
                    'sortable'  => false,
                    'index'     => 'stores',
                    'is_system' => true,
            ]);
        
        return parent::_prepareColumns();
    }
   
 
    public function getRowUrl($row)
    {
        return $this->getUrl('sales/order/view', ['order_id' => $row->getId()]);
    }

    public function getGridUrl()
    {
        return $this->getUrl('*/*/grid', ['_current'=>true]);
    }
  
}