<?php
/**
 * CedCommerce
  *
  * NOTICE OF LICENSE
  *
  * This source file is subject to the End User License Agreement (EULA)
  * that is bundled with this package in the file LICENSE.txt.
  * It is also available through the world-wide-web at this URL:
  * http://cedcommerce.com/license-agreement.txt
  *
  * @category  Ced
  * @package   Ced_LayBuy
  * @author    CedCommerce Core Team <connect@cedcommerce.com >
  * @copyright Copyright CEDCOMMERCE (http://cedcommerce.com/)
  * @license   https://cedcommerce.com/license-agreement.txt
  */

namespace Ced\LayBuy\Block\Adminhtml\Report\Details;

class Form extends \Magento\Backend\Block\Widget\Form\Generic
{
    /**
     * @var \Magento\Directory\Helper\Data
     */
    protected $_directoryHelper;

    /**
     * Form constructor.
     * @param \Magento\Backend\Block\Template\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param \Magento\Framework\Data\FormFactory $formFactory
     * @param \Magento\Directory\Helper\Data $directoryHelper
     * @param array $data
     */
    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Framework\Registry $registry,
        \Magento\Framework\Data\FormFactory $formFactory,
        \Magento\Directory\Helper\Data $directoryHelper,
        \Ced\LayBuy\Helper\Data $laybuyHelper,
        \Ced\LayBuy\Model\Report $report,
        \Magento\Framework\Locale\CurrencyInterface $localeCurrency,
        array $data = []
    )
    {
        parent::__construct($context, $registry, $formFactory, $data);
        $this->_directoryHelper = $directoryHelper;
        $this->_coreRegistry = $registry;
        $this->laybuyHelper = $laybuyHelper;
        $this->laybuyReport = $report;
        $this->_currencyInterface = $localeCurrency;
    }

    

    protected function _construct()
    {
        parent::_construct();
        $this->setId('laybuy_form_details');
        $this->setTitle(__('LayBuy Report Detail'));
    }

    /**
     * @return $this
     */
    protected function _prepareForm()
    {
        $form = $this->_formFactory->create([
                'data' => [
                    'id' => 'laybuy_form_details',
                   // 'action' => $this->getUrl('*/*/save', ['vendor_id' => $this->getRequest()->getParam('vendor_id')]),
                    //'method' => 'post',
                    'enctype' => 'multipart/form-data',
                ],
            ]
        );


        $model = $this->_coreRegistry->registry('current_laybuy_transaction');

        $settlement = $this->laybuyReport;

		$statuses = $this->laybuyReport->getStatuses();
		$status = $statuses[$model->getData('status')];
        $fieldsets = array(
            'reference_fieldset' => array(
                'fields' => array( 
					'paypal_profile_id' => array('label' => $settlement->getFieldLabel('paypal_profile_id'),'type'	=> 'label',),
					'laybuy_ref_no' => array('label' => $settlement->getFieldLabel('laybuy_ref_no'),'type'	=> 'label',),
                    'order_id' => array('label' => $settlement->getFieldLabel('order_id'),'type'	=> 'label',),
					
                ),
                'legend' => __('Reference Information')
            ),

            'transaction_fieldset' => array(
                'fields' => array(
					'status' => array(
                        'label' => $settlement->getFieldLabel('status'),
                        'value' => $status,
						'type'	=> 'label',
                    ),
                    'amount' => array(
                        'label' => $settlement->getFieldLabel('amount'),
                        'value' => $this->_currencyInterface
                                       ->getCurrency($model->getData('currency'))
									   ->toCurrency($model->getData('amount')),
						'type'	=> 'label',
                    ),
					'downpayment' => array(
                        'label' => $settlement->getFieldLabel('downpayment'),
                        'value' =>$model->getData('downpayment'),
						'type'	=> 'label',
                    ),
					'months' => array(
                        'label' => $settlement->getFieldLabel('months'),
                        'value' => $model->getData('months'),
						'type'	=> 'label',
                    ),
					'downpayment_amount' => array(
                        'label' => $settlement->getFieldLabel('downpayment_amount'),
                        'value' => $this->_currencyInterface
                                       ->getCurrency($model->getData('currency'))
									   ->toCurrency($model->getData('downpayment_amount')),
						'type'	=> 'label',
                    ),
					'payment_amounts' => array(
                        'label' => $settlement->getFieldLabel('payment_amounts'),
                        'value' => $this->_currencyInterface
                                       ->getCurrency($model->getData('currency'))
									   ->toCurrency($model->getData('payment_amounts')),
						'type'	=> 'label',
                    ),
					'first_payment_due' => array(
                        'label' => $settlement->getFieldLabel('first_payment_due'),
                        'value' => $this->laybuyHelper->formatDate($model->getData('first_payment_due'), \IntlDateFormatter::MEDIUM, true),
						'type'	=> 'label',
					),
					'last_payment_due' => array(
                        'label' => $settlement->getFieldLabel('last_payment_due'),
                        'value' => $this->laybuyHelper->formatDate($model->getData('last_payment_due'), \IntlDateFormatter::MEDIUM, true),
						'type'	=> 'label',
					),
					'report' => array(
                        'label' => $settlement->getFieldLabel('report'),
                        'value' => '',
						'type'	=> 'label',
						'after_element_html' => $model->getData('report'),
					),
					
                    
                ),
                'legend' => __('Payment Plan')
            ),

			'customer_fieldset' => array(
                'fields' => array(
                    'firstname' => array(
                        'label' => $settlement->getFieldLabel('firstname'),
                        'value' => $model->getData('firstname'),
						'type'	=> 'label',
                    ),
					'lastname' => array(
                        'label' => $settlement->getFieldLabel('lastname'),
                        'value' => $model->getData('lastname'),
						'type'	=> 'label',
                    ),
					'email' => array(
                        'label' => $settlement->getFieldLabel('email'),
                        'value' => $model->getData('email'),
						'type'	=> 'link',
						'href' => 'mailto:'.$model->getData('email'),
					),
					'address' => array(
                        'label' => $settlement->getFieldLabel('address'),
                        'value' => $model->getData('address'),
						'type'	=> 'label',
                    ),
					'suburb' => array(
                        'label' => $settlement->getFieldLabel('suburb'),
                        'value' => $model->getData('suburb'),
						'type'	=> 'label',
                    ),
					'state' => array(
                        'label' => $settlement->getFieldLabel('state'),
                        'value' => $model->getData('state'),
						'type'	=> 'label',
                    ),
					'country' => array(
                        'label' => $settlement->getFieldLabel('country'),
                        'value' => $model->getData('country'),
						'type'	=> 'label',
                    ),
					'postcode' => array(
                        'label' => $settlement->getFieldLabel('postcode'),
                        'value' => $model->getData('postcode'),
						'type'	=> 'label',
                    ),
                ),
                'legend' => __('Customer Information')
            ),
        );

        
        foreach ($fieldsets as $key => $data) {
            $fieldset = $form->addFieldset($key, array('legend' => $data['legend']));
            foreach ($data['fields'] as $id => $info) {
				if($info['type']=='link'){
					$fieldset->addField($id, $info['type'], array(
						'name'  => $id,
						'label' => $info['label'],
						'title' => $info['label'],
						'href' => $info['href'],
						'value' => isset($info['value']) ? $info['value'] : $model->getData($id),
						'after_element_html' => isset($info['after_element_html']) ? $info['after_element_html'] : '',
					));
				}else{
					$fieldset->addField($id, $info['type'], array(
						'name'  => $id,
						'label' => $info['label'],
						'title' => $info['label'],
						'value' => isset($info['value']) ? $info['value'] : $model->getData($id),
						'after_element_html' => isset($info['after_element_html']) ? $info['after_element_html'] : '',
					));
				}
            }
        }
        $this->setForm($form);
        $form->setUseContainer(true);
        return parent::_prepareForm();

        

    }
}