<?php
/**
 * CedCommerce
  *
  * NOTICE OF LICENSE
  *
  * This source file is subject to the End User License Agreement (EULA)
  * that is bundled with this package in the file LICENSE.txt.
  * It is also available through the world-wide-web at this URL:
  * http://cedcommerce.com/license-agreement.txt
  *
  * @category  Ced
  * @package   Ced_LayBuy
  * @author    CedCommerce Core Team <connect@cedcommerce.com >
  * @copyright Copyright CEDCOMMERCE (http://cedcommerce.com/)
  * @license   https://cedcommerce.com/license-agreement.txt
  */


namespace Ced\LayBuy\Block\Adminhtml\Report\Edit;

class Form extends \Magento\Backend\Block\Widget\Form\Generic
{
    /**
     * @var \Magento\Directory\Helper\Data
     */
    protected $_directoryHelper;

    /**
     * Form constructor.
     * @param \Magento\Backend\Block\Template\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param \Magento\Framework\Data\FormFactory $formFactory
     * @param \Magento\Directory\Helper\Data $directoryHelper
     * @param array $data
     */
    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Framework\Registry $registry,
        \Magento\Framework\Data\FormFactory $formFactory,
        \Magento\Directory\Helper\Data $directoryHelper,
        \Ced\LayBuy\Helper\Data $laybuyHelper,
        \Ced\LayBuy\Model\Report $report,
        \Magento\Framework\Locale\CurrencyInterface $localeCurrency,
        \Ced\LayBuy\Model\ResourceModel\Revise\CollectionFactory $collectionFactory,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Magento\Sales\Model\Order $orderData,
        array $data = []
    )
    {
        parent::__construct($context, $registry, $formFactory, $data);
        $this->_directoryHelper = $directoryHelper;
        $this->_coreRegistry = $registry;
        $this->laybuyHelper = $laybuyHelper;
        $this->laybuyReport = $report;
        $this->collectionFactory = $collectionFactory;
        $this->order = $orderData;
        $this->scopeConfig = $scopeConfig;
        $this->_currencyInterface = $localeCurrency;
    }

    

    protected function _construct()
    {
        parent::_construct();
        $this->setId('edit_form');
        $this->setTitle(__('LayBuy Report Form'));
    }

    /**
     * @return $this
     */
    protected function _prepareForm()
    {
        
        $calcUrl = $this->getUrl('*/*/docalc',array('_secure' => true)); /*'http://lay-buys.com/gateway/docalc.php'*/;
		$model = $this->_coreRegistry->registry('current_laybuy_transaction_edit');
		$newAmount = $model->getData('amount') - ($model->getData('downpayment_amount') + (((int)$model->getTransaction() - 2) * $model->getData('payment_amounts')));
		$isRevised = 0;
		$reviseagain = 0;
		if($model->getStatus() == -2) {
			$revised = $this->collectionFactory->create()
							->addFieldToFilter('transaction_id',array('eq'=>$model->getId()))
							->addFieldToFilter('type',array('eq'=>'new'))->getLastItem();
			if($revised && $revised->getId()) {
				$model = $revised;
				$newAmount = $model->getData('amount');
				$isRevised = $model->getId();
				$reviseagain = $isRevised;
				if($this->getRequest()->getParam('reviseagain')){
					$isRevised = 0;
				}
			}	
		}
		
        $settlement = $this->laybuyReport;

		$order_id = $model->getData('order_id');
		$order = $this->order->loadByIncrementId($order_id);
		$storeId = $order->getStoreId();
	
        
        $fieldsets = array(
            'reference_fieldset' => array(
                'fields' => array( 
					'mid' => array(
									'label' => $settlement->getFieldLabel('mid'),
									'type'	=> 'hidden',
									'value' => $this->scopeConfig->getValue('payment/laybuy/membership_number'),
									),
					'is_revised' => array(
									'label' => 'Is Revised',
									'type'  => 'hidden',
									'value' => $isRevised
 					),
					'paypal_profile_id' => array(
											'label' => $settlement->getFieldLabel('paypal_profile_id'),
											'type'	=> 'text',
											'readonly' => true,
											'after_element_html' => '<p class="note"><span>Readonly attribute</span></p>',
										   ),
					'laybuy_ref_no' => array(
											'label' => $settlement->getFieldLabel('laybuy_ref_no'),
											'type'	=> 'text',
											'readonly' => true,
											'after_element_html' => '<p class="note"><span>Readonly attribute</span></p>',
										),
                    'order_id' => array(
											'label' => $settlement->getFieldLabel('order_id'),
											'type'	=> 'text',
											'readonly' => true,
											'after_element_html' => '<p class="note"><span>Readonly attribute</span></p>',
											),
					
                ),
                'legend' => __('Reference Information')
            ),

            'transaction_fieldset' => array(
                'fields' => array(
                    'amount' => array(
                        'label' => $settlement->getFieldLabel('total_amount'),
                        'value' => $newAmount,
						'type'	=> 'hidden',
                    ),
					'pending_amount' => array(
                        'label' => $settlement->getFieldLabel('total_amount'),
                        'value' => $this->_currencyInterface
                                       ->getCurrency($model->getData('currency'))
									   ->toCurrency($newAmount),
						'type'	=> 'label',
                    ),
					'lay-buy' => array(
                        'label' => $settlement->getFieldLabel('Payment Type:'),
                        'value' => 1,
						'type'	=> 'hidden',
						'onclick'=> 'methodChange(1)',
						
						!$reviseagain || ($reviseagain && $model->getPaymentType())?'checked':'' => !$reviseagain || ($reviseagain && $model->getPaymentType())?'checked':'',
						//!$isRevised || ($isRevised && $model->getPaymentType())?'checked':'' => !$isRevised || ($isRevised && $model->getPaymentType())?'checked':'',
						//'after_element_html' => '<label for="lay-buy" class="inline">Lay-Buy</label>',
                    ),
					'buy-now' => array(
                        'label' => $settlement->getFieldLabel(''),
                        'value' => 0,
						'type'	=> 'radio',
						($reviseagain && !$model->getPaymentType())?'checked':'' => ($reviseagain && !$model->getPaymentType())?'checked':'',
						//($isRevised && !$model->getPaymentType())?'checked':'' => ($isRevised && !$model->getPaymentType())?'checked':'',
						'onclick'=> 'methodChange(0)',
						'after_element_html' => '<label for="buy-now" class="inline">Buy-Now</label>',
                    ),
					'pp' => array(
                        'label' => $settlement->getFieldLabel(''),
                        'value' => 1,
						'type'	=> 'hidden',
                    ),
					'pplan' => array(
                        'label' => $settlement->getFieldLabel(''),
                        'value' => 1,
						'type'	=> 'hidden',
                    ),
					'currency' => array(
                        'label' => $settlement->getFieldLabel('currency'),
                        'value' =>$model->getData('currency'),
						'type'	=> 'hidden',
                    ),
					'dp_amount' => array(
                        'label' => $settlement->getFieldLabel('dp_amount'),
                        'value' => $model->getData('downpayment'),
						'type'	=> 'select',
						'dy'	=> 1,
						'onchange' => 'rcalc()',
						'values' => $settlement->getArray('dp_amount',$newAmount,$storeId),
                    ),
					'months' => array(
                        'label' => $settlement->getFieldLabel('months_to_pay'),
                        'value' => $model->getData('months'),
						'type'	=> 'select',
						'onchange' => 'rcalc()',
						'values' => $settlement->getArray('months',$newAmount,$storeId),                                               
                        ),
					'preview' => array(
                        'label' => $settlement->getFieldLabel('preview'),
                        'value' => '',
						'type'	=> 'label',
						'after_element_html' => '<iframe name="preview-tbl" id="preview-tbl" style="width:100%; height:120px; border:0; margin:0; overflow:hidden" marginheight="0" marginwidth="0" noscroll></iframe>',
					),
					
                    'firstname' => array(
                        'label' => $settlement->getFieldLabel('firstname'),
                        'value' => $model->getData('firstname'),
						'type'	=> 'hidden',
                    ),
					'lastname' => array(
                        'label' => $settlement->getFieldLabel('lastname'),
                        'value' => $model->getData('lastname'),
						'type'	=> 'hidden',
                    ),
					'email' => array(
                        'label' => $settlement->getFieldLabel('email'),
                        'value' => $model->getData('email'),
						'type'	=> 'text',
						'readonly' => true,
						'after_element_html' => '<p class="note"><span>Readonly attribute.</span></p>',
					),
					'address' => array(
                        'label' => $settlement->getFieldLabel('address'),
                        'value' => $model->getData('address'),
						'type'	=> 'hidden',
                    ),
					'suburb' => array(
                        'label' => $settlement->getFieldLabel('suburb'),
                        'value' => $model->getData('suburb'),
						'type'	=> 'hidden',
                    ),
					'state' => array(
                        'label' => $settlement->getFieldLabel('state'),
                        'value' => $model->getData('state'),
						'type'	=> 'hidden',
                    ),
					'country' => array(
                        'label' => $settlement->getFieldLabel('country'),
                        'value' => $model->getData('country'),
						'type'	=> 'hidden',
                    ),
					'postcode' => array(
                        'label' => $settlement->getFieldLabel('postcode'),
                        'value' => $model->getData('postcode'),
						'type'	=> 'hidden',
                    ),
					'downpayment_amount' => array(
                        'label' => $settlement->getFieldLabel('downpayment_amount'),
                        'value' => $this->_currencyInterface
                                       ->getCurrency($model->getData('currency'))
									   ->toCurrency($model->getData('downpayment_amount')),
						'type'	=> 'hidden',
                    ),
					'payment_amounts' => array(
                        'label' => $settlement->getFieldLabel('payment_amounts'),
                        'value' => $this->_currencyInterface
                                       ->getCurrency($model->getData('currency'))
									   ->toCurrency($model->getData('payment_amounts')),
						'type'	=> 'hidden',
                    ),
					'first_payment_due' => array(
                        'label' => $settlement->getFieldLabel('first_payment_due'),
                        'value' => $this->laybuyHelper->formatDate($model->getData('first_payment_due'), \IntlDateFormatter::MEDIUM, true),
						'type'	=> 'hidden',
					),
					'last_payment_due' => array(
                        'label' => $settlement->getFieldLabel('last_payment_due'),
                        'value' => $this->laybuyHelper->formatDate($model->getData('last_payment_due'), \IntlDateFormatter::MEDIUM, true),
						'type'	=> 'hidden',
					),
					'report' => array(
                        'label' => $settlement->getFieldLabel('report'),
						'value' => 'New Description',
						'type'	=> 'hidden',
					),
					
                ),
                'legend' => __("Please Choose Buyer's New Payment Plan"),
			),
        );
		
		$submitUrl = $this->getUrl('*/*/save',array('_secure' => true,'id'=>$this->getRequest()->getParam('id')));
		
			 $form = $this->_formFactory->create([
                'data' => [
                    'id' => 'edit_form',
                    'action' => $submitUrl,
                    'method' => 'post',
                    'enctype' => 'multipart/form-data',
                ],
            ]
        );
			$form->setName('laybuy_revise_plan');
        foreach ($fieldsets as $key => $data) {
            $fieldset = $form->addFieldset($key, array('legend' => $data['legend']));
            foreach ($data['fields'] as $id => $info) {
				if($info['type']=='link'){
					$id = $fieldset->addField($id, $info['type'], array(
						'name'  => $id,
						'label' => $info['label'],
						'title' => $info['label'],
						'href' => $info['href'],
						'value' => isset($info['value']) ? $info['value'] : $model->getData($id),
						'after_element_html' => isset($info['after_element_html']) ? $info['after_element_html'] : '',
						'readonly' => isset($info['readonly'])?$info['readonly']:false,
						isset($info['values'])?'values':'' => isset($info['values'])?$info['values']:'',
						isset($info['onchange'])?'onchange':'' => isset($info['onchange'])?$info['onchange']:'',
						isset($info['onclick'])?'onclick':'' => isset($info['onclick'])?$info['onclick']:'',
						isset($info['checked'])?'checked':'' => isset($info['checked'])?$info['checked']:'',
						
					));
				}else{
					$id = $fieldset->addField($id, $info['type'], array(
						'name'  => $id,
						'label' => $info['label'],
						'title' => $info['label'],
						'value' => isset($info['value']) ? $info['value'] : $model->getData($id),
						'after_element_html' => isset($info['after_element_html']) ? $info['after_element_html'] : '',
						isset($info['readonly'])?'readonly':'' => isset($info['readonly'])?$info['readonly']:false,
						($isRevised && !isset($info['readonly']) && $info['type'] != 'hidden')? 'disabled':'' => ($isRevised && !isset($info['readonly']) && $info['type'] != 'hidden')?true:false, 
						isset($info['values'])?'values':'' => isset($info['values'])?$info['values']:'',
						isset($info['onchange'])?'onchange':'' => isset($info['onchange'])?$info['onchange']:'',
						isset($info['onclick'])?'onclick':'' => isset($info['onclick'])?$info['onclick']:'',
						isset($info['checked'])?'checked':'' => isset($info['checked'])?$info['checked']:'',
					));
					
				}
				if(isset($info['dy']) && isset($info['onchange']) && $function = $info['onchange']){
					$buyNowData = '';
					if ($reviseagain && !$model->getPaymentType()) {
						$buyNowData = 'setTimeout("document.getElementById(\"buy-now\").checked = true;methodChange(0);",200);';
						$funtionData = '
									
									var f = document.getElementById("preview-tbl");
								    f.src = "'.$calcUrl.'?currency="+document.laybuy_revise_plan.currency.value+"&amt="+document.laybuy_revise_plan.amount.value+"&init="+document.laybuy_revise_plan.dp_amount.value+"&mnth="+document.laybuy_revise_plan.months.value+"&rnd="+Math.random()+"&html=1";
									
									data = "'.$calcUrl.'?currency="+document.laybuy_revise_plan.currency.value+"&amt="+document.laybuy_revise_plan.amount.value+"&init="+document.laybuy_revise_plan.dp_amount.value+"&mnth="+document.laybuy_revise_plan.months.value+"&rnd="+Math.random();
									loadXMLDoc(data);';
					} else {
						$funtionData = 'document.getElementById("lay-buy").checked = true;
									
									var f = document.getElementById("preview-tbl");
								    f.src = "'.$calcUrl.'?currency="+document.laybuy_revise_plan.currency.value+"&amt="+document.laybuy_revise_plan.amount.value+"&init="+document.laybuy_revise_plan.dp_amount.value+"&mnth="+document.laybuy_revise_plan.months.value+"&rnd="+Math.random()+"&html=1";
									
									data = "'.$calcUrl.'?currency="+document.laybuy_revise_plan.currency.value+"&amt="+document.laybuy_revise_plan.amount.value+"&init="+document.laybuy_revise_plan.dp_amount.value+"&mnth="+document.laybuy_revise_plan.months.value+"&rnd="+Math.random();
									loadXMLDoc(data);';
					}
					$id->setAfterElementHtml(
					   '<script type="text/javascript">
							  function '.$function.'{
								'.$funtionData.'
							  }
							  
							  '.$buyNowData.'
							  setTimeout("'.$function.';",300);
							  function loadXMLDoc(url)
								{
									var xmlhttp;
									if (window.XMLHttpRequest)
									  {// code for IE7+, Firefox, Chrome, Opera, Safari
									  xmlhttp=new XMLHttpRequest();
									  }
									else
									  {// code for IE6, IE5
									  xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
									  }
									xmlhttp.onreadystatechange=function()
									  {
									  if (xmlhttp.readyState==4 && xmlhttp.status==200)
										{
											data = xmlhttp.responseText;
											data = data.split("~");	
											document.getElementById("downpayment_amount").value= data[0];
											document.getElementById("payment_amounts").value = data[1];
											document.getElementById("first_payment_due").value = data[2];
											document.getElementById("last_payment_due").value = data[3];
											document.getElementById("report").value= data[4];
											
										}
									  }
									xmlhttp.open("GET",url,true);
									xmlhttp.send();
								}
								function methodChange(value){
									/* alert(value); */
									document.getElementById("pp").value = value;
									document.getElementById("pplan").value = value;
									if(value){
										document.getElementById("buy-now").checked = false;
										document.getElementById("preview-tbl").parentNode.parentNode.style.display="block";
										document.getElementById("dp_amount").parentNode.parentNode.style.display="block";
										document.getElementById("months").parentNode.parentNode.style.display="block";
										document.getElementById("preview-tbl").parentNode.style.display="block";
										document.getElementById("dp_amount").parentNode.style.display="block";
										document.getElementById("months").parentNode.style.display="block";
									}else{
										document.getElementById("lay-buy").checked = false;
										console.log(document.getElementById("preview-tbl").parentNode.parentNode);
										document.getElementById("preview-tbl").parentNode.parentNode.style.display="none";
										document.getElementById("dp_amount").parentNode.parentNode.style.display="none";
										document.getElementById("months").parentNode.parentNode.style.display="none";
										document.getElementById("preview-tbl").parentNode.style.display="none";
										document.getElementById("dp_amount").parentNode.style.display="none";
										document.getElementById("months").parentNode.style.display="none";
									}
								} 
						</script>'
					);
				}
			}
        }
        $this->setForm($form);
        $form->setUseContainer(true);
        return parent::_prepareForm();

    }
}