<?php
/**
 * CedCommerce
  *
  * NOTICE OF LICENSE
  *
  * This source file is subject to the End User License Agreement (EULA)
  * that is bundled with this package in the file LICENSE.txt.
  * It is also available through the world-wide-web at this URL:
  * http://cedcommerce.com/license-agreement.txt
  *
  * @category  Ced
  * @package   Ced_LayBuy
  * @author    CedCommerce Core Team <connect@cedcommerce.com >
  * @copyright Copyright CEDCOMMERCE (http://cedcommerce.com/)
  * @license   https://cedcommerce.com/license-agreement.txt
  */

namespace Ced\LayBuy\Block\Adminhtml\Report;

class Grid extends \Magento\Backend\Block\Widget\Grid\Extended
{
    
    
    protected static $_states;
    
    
    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Backend\Helper\Data $backendHelper,
        \Ced\LayBuy\Model\ResourceModel\Report\CollectionFactory $reportCollection,
        \Magento\Sales\Model\Order\Config $orderConfig,
        \Ced\LayBuy\Helper\Data $laybuyHelper,
        \Magento\Store\Model\StoreManager $storeManager,
        array $data = []
    ) {
        
        $this->storeManager = $storeManager;
        $this->reportCollection = $reportCollection;
        $this->laybuyHelper = $laybuyHelper;
        $this->orderConfig = $orderConfig;
        
        parent::__construct($context, $backendHelper, $data);
    }
 
    /**
     * @return void
     */
    protected function _construct()
    {
       
        parent::_construct();
        $this->setId('sales_laybuy_report_grid');
        $this->setDefaultSort('id');
        $this->setDefaultDir('DESC');
        $this->setSaveParametersInSession(true);
        $this->setUseAjax(true);
        $this->setVarNameFilter('post_filter');
    }
 
    /**
     * @return $this
     */
    protected function _prepareCollection()
    {
        
		$collection = $this->reportCollection->create();
		$this->setCollection($collection);
		return parent::_prepareCollection();
		

    }
 

    /**
     * @return $this
     * @throws \Exception
     */
    protected function _prepareColumns()
    {
        
       $this->addColumn('created_at', array(
			'header'        => __('Created At'),
			'align'         => 'left',
			'filter_index'  => 'created_at',
			'index'         => 'created_at',
			'type'          => 'datetime',
		));
		$this->addColumn('order_id', array(
			'header'        => __('Order#'),
			'align'         => 'right',
			'filter_index'  => 'order_id',
			'index'         => 'order_id',
			'type'          => 'number',
			'renderer'  => '\Ced\LayBuy\Block\Adminhtml\Report\Renderer\Order',
		));
		
		$this->addColumn('amount', array(
			'header'        => __('Amount'),
			'align'         => 'left',
			'filter_index'  => 'amount',
			'index'         => 'amount',
			'type'          => 'price',
			'currency_code' => $this->storeManager->getStore()->getBaseCurrency()->getCode(),
		));
		$this->addColumn('downpayment', array(
			'header'        => __('Down Payment %'),
			'align'         => 'right',
			'filter_index'  => 'downpayment',
			'index'         => 'downpayment',
			'type'          => 'range',
		));
		$this->addColumn('months', array(
			'header'        => __('Months'),
			'align'         => 'left',
			'filter_index'  => 'months',
			'index'         => 'months',
			'type'          => 'range',
		));
		$this->addColumn('downpayment_amount', array(
			'header'        => __('Down Payment Amount'),
			'align'         => 'right',
			'filter_index'  => 'downpayment_amount',
			'index'         => 'downpayment_amount',
			'type'          => 'price',
			'currency_code' => $this->storeManager->getStore()->getBaseCurrency()->getCode(),
		));
		$this->addColumn('payment_amounts', array(
			'header'        => __('Payment Amounts'),
			'align'         => 'left',
			'filter_index'  => 'payment_amounts',
			'index'         => 'payment_amounts',
			'type'          => 'price',
			'currency_code' => $this->storeManager->getStore()->getBaseCurrency()->getCode(),
		));
		$this->addColumn('first_payment_due', array(
			'header'        => __('First Payment Due'),
			'align'         => 'right',
			'filter_index'  => 'first_payment_due',
			'index'         => 'first_payment_due',
			'type'          => 'datetime',
		));
		$this->addColumn('last_payment_due', array(
			'header'        => __('Last Payment Due'),
			'align'         => 'left',
			'filter_index'  => 'last_payment_due',
			'index'         => 'last_payment_due',
			'type'          => 'datetime',
		));
		$this->addColumn('status', array(
			'header'        => __('Status'),
			'align'         => 'right',
			'filter_index'  => 'status',
			'index'         => 'status',
			'type'      => 'options',
			'options'   => $this->laybuyHelper->getStatuses(),
		));
	//	$this->addExportType('*/*/exportCsv', __('CSV'));
	//	$this->addExportType('*/*/exportXml', __('XML'));
        
        return parent::_prepareColumns();
    }
   
 
    public function getRowUrl($row)
  {
      return $this->getUrl('*/*/details', ['_secure' => true,'id' => $row->getId(),'fbr'=>$row->isFetchRequire()]);
  }

    public function getGridUrl()
    {
        return $this->getUrl('*/*/grid', ['_current'=>true]);
    }
  
}