<?php
/**
 * CedCommerce
  *
  * NOTICE OF LICENSE
  *
  * This source file is subject to the End User License Agreement (EULA)
  * that is bundled with this package in the file LICENSE.txt.
  * It is also available through the world-wide-web at this URL:
  * http://cedcommerce.com/license-agreement.txt
  *
  * @category  Ced
  * @package   Ced_LayBuy
  * @author    CedCommerce Core Team <connect@cedcommerce.com >
  * @copyright Copyright CEDCOMMERCE (http://cedcommerce.com/)
  * @license   https://cedcommerce.com/license-agreement.txt
  */
namespace Ced\LayBuy\Block\Info;

class Laybuy extends \Magento\Payment\Block\Info
{
    protected $_currentTransaction;
    /**
     * @var string
     */
    protected $_payableTo;

    /**
     * @var string
     */
    protected $_mailingAddress;

    /**
     * @var string
     */
    protected $_template = 'Ced_LayBuy::laybuy/info/laybuy.phtml';


        public function __construct(
            \Magento\Framework\View\Element\Template\Context $context,
            \Magento\Customer\Model\Session $session,
            \Ced\LayBuy\Model\Report $laybuyReport,
            \Magento\Sales\Model\Order $orderdata,
            \Magento\Framework\Event\Manager $eventManager,
    		array $data = []
    	)
        {
            $this->eventManager = $eventManager;
            parent::__construct($context,$data);
            $this->laybuyReport = $laybuyReport;
            $this->order = $orderdata;
        }

    /**
     * Enter description here...
     *
     * @return string
     */
    public function getPayableTo()
    {
        if ($this->_payableTo === null) {
            $this->_convertAdditionalData();
        }
        return $this->_payableTo;
    }

    /**
     * Enter description here...
     *
     * @return string
     */
    public function getMailingAddress()
    {
        if ($this->_mailingAddress === null) {
            $this->_convertAdditionalData();
        }
        return $this->_mailingAddress;
    }

    /**
     * @deprecated 100.1.1
     * @return $this
     */
    protected function _convertAdditionalData()
    {
        $this->_payableTo = $this->getInfo()->getAdditionalInformation('payable_to');
        $this->_mailingAddress = $this->getInfo()->getAdditionalInformation('mailing_address');
        return $this;
    }

    
    
    
    protected function _prepareSpecificInformation($transport = null)
    {
        if (null === $this->_paymentSpecificInformation) {
            if (null === $transport) {
                $transport = new \Magento\Framework\DataObject();
            } elseif (is_array($transport)) {
                $transport = new \Magento\Framework\DataObject($transport);
            }
            $this->eventManager->dispatch('payment_info_block_prepare_specific_information', [
                'transport' => $transport,
                'payment'   => $this->getInfo(),
				'transaction'=> $this->getTransaction(),
                'block'     => $this,
            ]);
            $this->_paymentSpecificInformation = $transport;
        }
        return $this->_paymentSpecificInformation;
    }
    
    /**
     * @return string
     */
    public function toPdf()
    {
        $this->setTemplate('Ced_LayBuy::info/pdf/laybuy.phtml');
        return $this->toHtml();
    }
    
     
	
	
	public function getTransaction(){
		if(null === $this->_currentTransaction){
			$orderId = $this->getInfo()->getParentId();
			$orderIncrementId = $this->order->load($orderId)->getIncrementId();
			$this->_currentTransaction = $this->laybuyReport->getCollection()->addFieldToFilter('order_id',['eq'=>$orderIncrementId]);
		}
		return $this->_currentTransaction;
	}
}
