<?php
/**
 * CedCommerce
  *
  * NOTICE OF LICENSE
  *
  * This source file is subject to the End User License Agreement (EULA)
  * that is bundled with this package in the file LICENSE.txt.
  * It is also available through the world-wide-web at this URL:
  * http://cedcommerce.com/license-agreement.txt
  *
  * @category  Ced
  * @package   Ced_LayBuy
  * @author    CedCommerce Core Team <connect@cedcommerce.com >
  * @copyright Copyright CEDCOMMERCE (http://cedcommerce.com/)
  * @license   https://cedcommerce.com/license-agreement.txt
  */

namespace Ced\LayBuy\Controller\Revise;

class Success extends \Magento\Framework\App\Action\Action
{
    /**
     * @var \Magento\Framework\View\Result\PageFactory
     */
    protected $resultPageFactory;
    /**
     * @var \Magento\Customer\Model\Session
     */
    protected $_custmerSesion;
    /**
     * @var
     */
    protected $_resultForwardFactory;
    /**
     * @var \Magento\Framework\App\Config\ScopeConfigInterface
     */
    protected $_scopeConfig;

    /**
     * Index constructor.
     * @param \Magento\Framework\App\Action\Context $context
     * @param \Magento\Customer\Model\Session $this->checkoutSesion
     * @param \Magento\Framework\View\Result\PageFactory $resultPageFactory
     * @param \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
     */
    public function __construct(
    	\Magento\Framework\App\Action\Context $context,
    	\Magento\Checkout\Model\Session $checkoutSession,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \Magento\Framework\Stdlib\DateTime\TimezoneInterface $timezone,
        \Magento\Framework\Stdlib\DateTime\DateTime $dateTime,
        \Ced\LayBuy\Model\ReviseFactory $revise,
        \Ced\LayBuy\Helper\Data $helper,
        \Magento\Sales\Model\Order $orderData,
        \Ced\LayBuy\Model\ReportFactory $report,
        \Magento\Framework\Stdlib\DateTime $datedata,
        \Magento\Framework\Locale\CurrencyInterface $localeCurrency
    ) {
        $this->resultPageFactory = $resultPageFactory;
        $this->checkoutSesion = $checkoutSession;
        $this->_timezone = $timezone;
        $this->datetime = $dateTime;
        $this->revise = $revise;
        $this->laybuyhelper = $helper;
        $this->order = $orderData;
        $this->report = $report;
        $this->date = $datedata;
        $this->_currencyInterface = $localeCurrency;
        parent::__construct($context);
    }

    /**
     * @return \Magento\Framework\App\ResponseInterface|\Magento\Framework\Controller\ResultInterface|\Magento\Framework\View\Result\Page|void
     */
    public function execute()
    {
    	
		$format = $this->_timezone->getDateFormat(\IntlDateFormatter::MEDIUM);
		$status = array_change_key_case($this->getRequest()->getParams(),CASE_LOWER);
		
		if(isset($status['result']) && $status['result']=='FAILURE'){
			$this->_forward('cancel');
		}
		
		try{
			$currentDate = $this->datetime->date('Y-m-d h:i:s');
			$status['_secure'] = true;
		//	$str = print_r($status, true);
			$revise = $this->revise->create()->load($status['merchants_ref_no']);
			$state = 0;
			if(!isset($status['downpayment']) && !$revise->getPaymentType()){
				$status['downpayment'] = 100;
				$status['months'] = 0;
				$status['downpayment_amount'] = $status['amount'];
				$status['payment_amounts'] = 0;
				$status['first_payment_due'] = $currentDate;
				$status['last_payment_due'] = $currentDate;
				$status['paypal_profile_id'] = 'n/a';
				if($this->laybuyhelper->processOrder($status['custom'],1))
					$state = 1;	
			}
	
			$status['first_payment_due'] = date('Y-m-d h:i:s', strtotime(str_replace('/','-',$status['first_payment_due'])));
			$status['last_payment_due'] = date('Y-m-d h:i:s', strtotime(str_replace('/','-',$status['last_payment_due'])));
			
			$this->checkoutSesion->setQuoteId($this->checkoutSesion->getLayBuyStandardQuoteId(true));
			$this->checkoutSesion->getQuote()->setIsActive(false)->save();
			
			$order = $this->order->loadByIncrementId($status['custom']);
			
			if($order && $order->getId()){
				if($order->getCreatedAt() > $currentDate) $currentDate = $order->getCreatedAt();
				$createdAt = $this->date->formatDate($currentDate);
				$payment_info = $order->getPayment()->getData('additional_information');
				
				
				$order->getPayment()->setData('laybuy_init',$status['downpayment'])
									->setData('laybuy_months',$status['months']);
				$order->save();
				
			
				$newStr = '<div class="grid"><div class="hor-scroll"><table cellspacing=0 class="data"><thead><tr class="headings"><th colspan=2 class=" no-link" style="text-align: center;"><span class="nobr">Instalment</span></th><th class=" no-link" style="text-align: center;"><span class="nobr">Date</span></th><th class=" no-link" style="text-align: center;"><span class="nobr">PayPal Transaction ID</span></th><th class=" no-link" style="text-align: center;"><span class="nobr">Status</span></th></tr></thead>';				
				$newStr .= '<colgroup>								
								<col width="100">								
								<col width="75">								
								<col width="183">								
								<col width="183">								
								<col width="98">							
							</colgroup>';				
				$months = (int)$status['months'];				
				$newStr .= '<tbody><tr class="even" ><td style="text-align: center;"> DP: </td><td style="text-align: center;"> '.$this->_currencyInterface->getCurrency($status['currency'])->toCurrency($status['downpayment_amount']).' </td>'.						  
							'<td style="text-align: center;"> '.$createdAt.' </td>'.						  
							'<td style="text-align: center;">'.$status['dp_paypal_txn_id'].'</td>'.						  
							'<td style="text-align: center;"> Completed </td></tr>';								
				
				for($month=1;$month<=$months;$month++){					
					$newStr .= '<tr ';					
					if($month%2==0)						
						$newStr .= 'class="even"';					
					$newStr .= '>';					
					$newStr .= '<td style="text-align: center;"> Month '.$month.': </td><td style="text-align: center;"> '.$this->_currencyInterface->getCurrency($status['currency'])->toCurrency($status['payment_amounts']).' </td>';									   					
					$date = date("Y-m-d h:i:s", strtotime($status['first_payment_due'] . " +".($month-1)." month"));					
					$date = $this->date->formatDate($date);					
					$newStr .= '<td style="text-align: center;"> '.$date.' </td>';					
					$newStr .= 	'<td style="text-align: center;">&nbsp;</td>';					
					$newStr .= 	'<td style="text-align: center;"> Pending </td></tr>';									
				}
				
				$newStr .= '</tbody></table></div></div>';				
				$model = $this->report->create()->setData($status)														
														->setOrderId($status['custom'])														
														->setStoreId($order->getStoreId())														
														->setCreatedAt($currentDate)														
														->setStatus($state)														
														->setReport($newStr)														
														/* ->setTransaction(0) */														
														->save();
				$oldTransaction = $this->report->create()->load($revise->getTransactionId());
				$newStrReport = preg_replace('/Pending/i', 'Canceled', $oldTransaction->getReport());
				if($this->laybuyhelper->cancelPaypalProfile($oldTransaction->getPaypalProfileId(),$oldTransaction->getStoreId())){
					$oldTransaction->setStatus(2)->setReport($newStrReport)->save();
					$revise->delete();
				}
			}
			$this->checkoutSesion->addSuccess(__('Payment was revised successfully.'));
		}catch(\Exception $e){
			$status = array_change_key_case($this->getRequest()->getParams(),CASE_LOWER);
			if($status){
			//	$str = print_r($status, true);
				$this->checkoutSesion->addError(__('Payment Recieved.But transaction not saved please contact with us.'));
			}else{
				$this->checkoutSesion->addError(__('Try Again Later.'));
			}
		}		
        return $this->_redirect('checkout/onepage/success',['_secure' => true]);
     
    }
}