<?php
/**
 * CedCommerce
  *
  * NOTICE OF LICENSE
  *
  * This source file is subject to the End User License Agreement (EULA)
  * that is bundled with this package in the file LICENSE.txt.
  * It is also available through the world-wide-web at this URL:
  * http://cedcommerce.com/license-agreement.txt
  *
  * @category  Ced
  * @package   Ced_LayBuy
  * @author    CedCommerce Core Team <connect@cedcommerce.com >
  * @copyright Copyright CEDCOMMERCE (http://cedcommerce.com/)
  * @license   https://cedcommerce.com/license-agreement.txt
  */
namespace Ced\LayBuy\Controller\Standard;

class Success extends \Magento\Framework\App\Action\Action
{
    /**
     * @var \Magento\Framework\View\Result\PageFactory
     */
    protected $resultPageFactory;
    /**
     * @var \Magento\Customer\Model\Session
     */
    protected $_custmerSesion;
    /**
     * @var
     */
    protected $_resultForwardFactory;
    /**
     * @var \Magento\Framework\App\Config\ScopeConfigInterface
     */
    protected $_scopeConfig;

    /**
     * Index constructor.
     * @param \Magento\Framework\App\Action\Context $context
     * @param \Magento\Customer\Model\Session $this->checkoutSesion
     * @param \Magento\Framework\View\Result\PageFactory $resultPageFactory
     * @param \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
     */
    public function __construct(
    	\Magento\Framework\App\Action\Context $context,
    	\Magento\Checkout\Model\Session $checkoutSession,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \Magento\Framework\Stdlib\DateTime\TimezoneInterface $timezone,
        \Magento\Framework\Stdlib\DateTime\DateTime $dateTime,
        \Ced\LayBuy\Model\ReviseFactory $revise,
        \Ced\LayBuy\Helper\Data $helper,
        \Magento\Sales\Model\Order $orderData,
        \Ced\LayBuy\Model\ReportFactory $report,
        \Magento\Framework\Stdlib\DateTime $datedata,
        \Magento\Framework\Locale\CurrencyInterface $localeCurrency,
        \Magento\Sales\Model\Order\Email\Sender\OrderSender $orderSender
    ) {
        $this->resultPageFactory = $resultPageFactory;
        $this->checkoutSesion = $checkoutSession;
        $this->_timezone = $timezone;
        $this->datetime = $dateTime;
        $this->revise = $revise;
        $this->laybuyhelper = $helper;
        $this->order = $orderData;
        $this->report = $report;
        $this->date = $datedata;
        $this->_currencyInterface = $localeCurrency;
        $this->_orderSender = $orderSender;
        parent::__construct($context);
    }

    /**
     * @return \Magento\Framework\App\ResponseInterface|\Magento\Framework\Controller\ResultInterface|\Magento\Framework\View\Result\Page|void
     */
    public function execute()
    {
    	
		$status = array_change_key_case($this->getRequest()->getParams(),CASE_LOWER);
		
		if(isset($status['result']) && $status['result']=='FAILURE'){
			$this->_forward('cancel');
		}
		$session = $this->checkoutSesion;

		try{
			$status['_secure'] = true;
		//	$str = print_r($status, true);
			/* $status['first_payment_due'] = '13/12/13';
			$status['last_payment_due'] = '13/01/14'; */
			$status['first_payment_due'] = date('Y-m-d h:i:s', strtotime(str_replace('/','-',$status['first_payment_due'])));
			$status['last_payment_due'] = date('Y-m-d h:i:s', strtotime(str_replace('/','-',$status['last_payment_due'])));
			/*$session->setQuoteId($session->getLayBuyStandardQuoteId(true));
			$this->checkoutSesion->getQuote()->setIsActive(false)->save();*/
			
			$order= $this->order->loadByIncrementId($status['custom']);
			$payment_info = [];
			if($order && $order->getId()){
				
				$orderStatus = $this->laybuyhelper->getStoreConfig('payment/laybuy/order_status');
				
				if($this->laybuyhelper->getStoreConfig('payment/laybuy/order_status')=='processing'){
				   try{
				            $payment = $order->getPayment();
				            $payment_info = $order->getPayment()->getData('additional_information');
				            $payment_info['transactions'][$status['paypal_profile_id']][] = array(
													'txnID' => $status['dp_paypal_txn_id'],
													'type'	=> 'd',
													'paymentStatus' => 'Completed',
													'paymentDate' => $order->getCreatedAt(),
													'amount' => $status['downpayment_amount']
												);
				            $order->getPayment()->setData('additional_information',$payment_info);
				
				
					        $msg = __('Payment Recieved Successfully');
        					$payment->setTransactionId($status['dp_paypal_txn_id'])
        					->setPreparedMessage($this->_createComment($msg,$order))
        					->setShouldCloseParentTransaction(true)
        					->setIsTransactionClosed(false)
        					->registerCaptureNotification(
        							$order->getGrandTotal(),
        							true
        					);
        					$order->save();
        					
        					$invoice = $payment->getCreatedInvoice();
        					if ($invoice && !$order->getEmailSent()) {
        						$this->_orderSender->send($order);
        						$order->addStatusHistoryComment(
        								__('You notified customer about invoice #%1.', $invoice->getIncrementId())
        						)->setIsCustomerNotified(
        								true
        						)->save();
        					}
        				}catch(\Exception $e){
        				    echo $e->getMessage();die;
        					
        				} 
				}else{
				    $order->setState($orderStatus)->setStatus($orderStatus);

                    $order->save();
				}
				$createdAt = $this->laybuyhelper->formatDate($order->getCreatedAt(),\IntlDateFormatter::MEDIUM);
				$newStr = '<div class="grid"><div class="hor-scroll"><table cellspacing=0 class="data"><thead><tr class="headings"><th colspan=2 class=" no-link" style="text-align: center;"><span class="nobr">Installment</span></th><th class=" no-link" style="text-align: center;"><span class="nobr">Date</span></th><th class=" no-link" style="text-align: center;"><span class="nobr">PayPal Transaction ID</span></th><th class=" no-link" style="text-align: center;"><span class="nobr">Status</span></th></tr></thead>';
				$newStr .= '<colgroup>
								<col width="100">
								<col width="75">
								<col width="183">
								<col width="183">
								<col width="98">
							</colgroup>';
				$months = (int)$status['months'];
				$newStr .= '<tbody><tr class="even" ><td style="text-align: center;"> DP: </td><td style="text-align: center;"> '.$this->_currencyInterface->getCurrency($status['currency'])
									   ->toCurrency($status['downpayment_amount']).' </td>'.
						  '<td style="text-align: center;"> '.$createdAt.' </td>'.
						  '<td style="text-align: center;">'.$status['dp_paypal_txn_id'].'</td>'.
						  '<td style="text-align: center;"> Completed </td></tr>';
				for($month=1;$month<=$months;$month++){
					$newStr .= '<tr ';
					if($month%2==0)
						$newStr .= 'class="even"';
					$newStr .= '>';
					$newStr .= '<td style="text-align: center;"> Month '.$month.': </td><td style="text-align: center;"> '.$this->_currencyInterface->getCurrency($status['currency'])
									   ->toCurrency($status['payment_amounts']).' </td>';
					$date = date("Y-m-d h:i:s", strtotime($status['first_payment_due'] . " +".($month-1)." month"));
					$date = $this->laybuyhelper->formatDate($date,\IntlDateFormatter::MEDIUM);
					$newStr .= '<td style="text-align: center;"> '.$date.' </td>';
					$newStr .= 	'<td style="text-align: center;">&nbsp;</td>';
					$newStr .= 	'<td style="text-align: center;"> Pending </td></tr>';
				}
				$newStr .= '</tbody></table></div></div>';
				$model = $this->report->create()->setData($status)
														->setOrderId($status['custom'])
														->setStoreId($order->getStoreId())
														->setCreatedAt($order->getCreatedAt())
														->setStatus(0)
														->setReport($newStr)
														/* ->setTransaction(0) */
														->save();
			}
			$this->messageManager->addSuccess(__('Payment was recieved successfully.'));
		}catch(\Exception $e){
		    echo $e->getMessage();die;
			$status = array_change_key_case($this->getRequest()->getParams(),CASE_LOWER);
			if($status){
			//	$str = print_r($status, true);
				$this->messageManager->addError(__('Payment Recieved.But transaction not saved please contact us.'));
			
			}else{
				$this->messageManager->addError(__('Try Again Later.'));
			}
		}	
		
       return  $this->_redirect('checkout/onepage/success',['_secure' => true]);
     
    }
    
    protected function _createComment($message = '',$order)
	{
		if ($message != '')
		{
			$message = $order->addStatusHistoryComment($message);
			$message->setIsCustomerNotified(null);
		}
	
		return $message;
	}
}