<?php 
/**
 * CedCommerce
  *
  * NOTICE OF LICENSE
  *
  * This source file is subject to the End User License Agreement (EULA)
  * that is bundled with this package in the file LICENSE.txt.
  * It is also available through the world-wide-web at this URL:
  * http://cedcommerce.com/license-agreement.txt
  *
  * @category  Ced
  * @package   Ced_LayBuy
  * @author    CedCommerce Core Team <connect@cedcommerce.com >
  * @copyright Copyright CEDCOMMERCE (http://cedcommerce.com/)
  * @license   https://cedcommerce.com/license-agreement.txt
  */
 
namespace Ced\LayBuy\Helper;
 use Magento\Framework\App\Helper;


class Config extends \Magento\Framework\App\Helper\AbstractHelper
{
    protected $_storeId = null;
    /**
     * Data constructor.
     * @param Helper\Context $context
     * @param \Magento\Framework\ObjectManagerInterface $objectManager
     */
	public function __construct(
		Helper\Context $context,
		\Ced\LayBuy\Model\Report $laybuyReport,
		\Ced\LayBuy\Model\ResourceModel\Report\CollectionFactory $reportCollection,
		\Magento\Sales\Model\Service\InvoiceService $invoiceService,
		\Magento\Sales\Model\OrderFactory $orderFactory,
		\Magento\Framework\DB\Transaction $transaction,
		\Magento\Framework\UrlInterface $url,
		\Magento\Store\Model\StoreManagerInterface $storeManager,
		\Magento\Catalog\Model\ProductRepository $productRepository,
		Data $helperData
	) 
	{
		parent::__construct($context);
		$this->laybuyReport = $laybuyReport;
		$this->reportCollection = $reportCollection;
		$this->orderFactory = $orderFactory;
		$this->_invoiceService = $invoiceService;
		$this->_transaction = $transaction;
		$this->_storeManager = $storeManager;
		$this->url = $url;
		$this->laybuyHelper = $helperData;
		$this->productRepository = $productRepository;
	}

    public function getStoreId(){
		if(empty($this->_storeId))
			$this->_storeId = $this->_storeManager->getStore()->getId();
		return $this->_storeId;
	}
	/*
	 * Get the gateway submit url
	 */
	public function getSubmitUrl(){
		return $this->scopeConfig->getValue('payment/laybuy/submit_url',\Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->getStoreId());
	}	
	/*
	 * For form filed At LayBuy gateway
	 */
	public function getStandardCheckoutFormFields($data){
		return $data;
	}
	/*
	 * For form field At LayBuy gateway
	 */
	public function extractAndPrepareRequiredValueForFormFields($chekoutSession){
		$descKey = 'DESC';		
		$data = array();		
		$storeId = $this->getStoreId();
		$orderId = $chekoutSession->getLastRealOrder()->getIncrementId();
		
		if($orderId){
			$order = $this->orderFactory->create()->loadByIncrementId($orderId);
			$customerOptions = $this->laybuyHelper->getInstalmentData($order->getPayment());
			$amount = $order->getData('grand_total');
			$currency_code = $this->_storeManager->getStore()->getCurrentCurrencyCode();
			$email = $order->getData('customer_email');
			/* for adding product's description */
			$description ='';
			if($this->scopeConfig->getValue('payment/laybuy/multipledesc',\Magento\Store\Model\ScopeInterface::SCOPE_STORE,$storeId)){
				foreach($order->getAllItems() as $_product){
					$item = $_product;
					$_product = $this->productRepository->getById($_product->getProductId());
					if($description){
						$description .= ' <br/> ';
					}
					$description .= strip_tags($_product->getShortDescription()).'(Qty '.(int)$item->getData('qty_ordered').')';
				}
			}else{	
				$definedDescription = $this->scopeConfig->getValue('payment/laybuy/desc',\Magento\Store\Model\ScopeInterface::SCOPE_STORE,$storeId);
				$description .= $definedDescription;			
			}
			$data = array(
						'AMOUNT'	=> number_format($amount, 2, '.', ''),
						'MEMBER' 	=> $this->scopeConfig->getValue('payment/laybuy/membership_number',\Magento\Store\Model\ScopeInterface::SCOPE_STORE,$storeId),
						'CURRENCY'  => $currency_code,
						'RETURNURL' => $this->url->getUrl('laybuy/standard/success',['_secure'=>true]),
						'CANCELURL' => $this->url->getUrl('laybuy/standard/cancel',['_secure'=>true]),
						 $descKey	=> $description,
						'CUSTOM'	=> $orderId,
						'EMAIL' 	=> $email,
						);
			$data['BYPASSLAYBUY'] = $this->scopeConfig->getValue('payment/laybuy/bypasslaybuy',\Magento\Store\Model\ScopeInterface::SCOPE_STORE);
			$data['VERSION'] = '0.2';
			$MAXD   = $this->scopeConfig->getValue('payment/laybuy/maxd',\Magento\Store\Model\ScopeInterface::SCOPE_STORE,$storeId);
			$MIND   = $this->scopeConfig->getValue('payment/laybuy/mind',\Magento\Store\Model\ScopeInterface::SCOPE_STORE,$storeId);
			$IMAGE  = $this->scopeConfig->getValue('payment/laybuy/image',\Magento\Store\Model\ScopeInterface::SCOPE_STORE,$storeId);
			if(isset($customerOptions['MONTHS']) && $customerOptions['MONTHS']){
				$MONTHS = $customerOptions['MONTHS'];
			}elseif($chekoutSession->getLaybuyInfo()){
			    $MONTHS = $chekoutSession->getLaybuyInfo()['mnth'];
			}else{
				$MONTHS = $this->scopeConfig->getValue('payment/laybuy/months',\Magento\Store\Model\ScopeInterface::SCOPE_STORE,$storeId);
			}
			if(isset($customerOptions['INIT']) && $customerOptions['INIT']){
				$INIT = $customerOptions['INIT'];
			}elseif($chekoutSession->getLaybuyInfo()){
				$INIT = $chekoutSession->getLaybuyInfo()['init'];
			}else{
			    $INIT=0;
			}
			/* Restrict maxiumum possible downpayment percentage to less then or equal 50% */
			if(!$MIND || $MIND<20 || $MIND>50){
				$MIND = 20;
			}			
			if(!$MAXD || $MAXD<20 || $MAXD>50){
				$MAXD = 50;
			}
			if($IMAGE){
				$IMAGE = $this->_storeManager->getStore()->getBaseUrl(\Magento\Framework\UrlInterface::URL_TYPE_MEDIA)."laybuy/".$IMAGE;
			}else{
				$IMAGE = 'http://lay-buys.com/lb2.jpg';
			}
			if(!$MONTHS || $MONTHS<0){
				$MONTHS = 3;
			}	
			if($INIT){
				$data['INIT'] = $INIT;
			}
			$data['MIND'] = $MIND;
			$data['MAXD'] = $MAXD;
			$data['IMAGE'] = $IMAGE;
			$data['MONTHS'] = $MONTHS;	
		}
//	print_r($data);die;
		return $data;
	}
    
}