<?php 
/**
 * CedCommerce
  *
  * NOTICE OF LICENSE
  *
  * This source file is subject to the End User License Agreement (EULA)
  * that is bundled with this package in the file LICENSE.txt.
  * It is also available through the world-wide-web at this URL:
  * http://cedcommerce.com/license-agreement.txt
  *
  * @category  Ced
  * @package   Ced_LayBuy
  * @author    CedCommerce Core Team <connect@cedcommerce.com >
  * @copyright Copyright CEDCOMMERCE (http://cedcommerce.com/)
  * @license   https://cedcommerce.com/license-agreement.txt
  */
 
namespace Ced\LayBuy\Helper;
 use Magento\Framework\App\Helper;

class Data extends \Magento\Framework\App\Helper\AbstractHelper
{
    protected $_matchingData = null;
    /**
     * Data constructor.
     * @param Helper\Context $context
     * @param \Magento\Framework\ObjectManagerInterface $objectManager
     */
	public function __construct(
		Helper\Context $context,
		\Ced\LayBuy\Model\Report $laybuyReport,
		\Ced\LayBuy\Model\ResourceModel\Report\CollectionFactory $reportCollection,
		\Magento\Sales\Model\Service\InvoiceService $invoiceService,
		\Magento\Sales\Model\OrderFactory $orderFactory,
		\Magento\Framework\DB\Transaction $transaction,
		\Magento\Framework\UrlInterface $url,
		\Magento\Store\Model\StoreManagerInterface $storeManager,
		\Magento\Framework\Stdlib\DateTime\TimezoneInterface $_localeDate,
		\Magento\Framework\Locale\CurrencyInterface $localeCurrency
	) 
	{
		parent::__construct($context);
		$this->laybuyReport = $laybuyReport;
		$this->reportCollection = $reportCollection;
		$this->orderFactory = $orderFactory;
		$this->_invoiceService = $invoiceService;
		$this->_transaction = $transaction;
		$this->_storeManager = $storeManager;
		$this->url = $url;
		$this->_localeDate = $_localeDate;
		$this->_currencyInterface = $localeCurrency;
	}

    public function getStatuses(){
		return [
              '0' => __("Pending"),
			  '1' => __("Completed"),
              '-1'=> __('Cancelled'),
			   '-2' => __('Revise Requested'),
			  '2' => __('Revised'),
          ];
	}
	
	public function getInstalmentData($payment,$key = '') {
		if(!$payment) return false;
		if(empty($key)) {
			$customerOptions['INIT'] = $payment->getData('laybuy_init');
			$customerOptions['MONTHS'] = $payment->getData('laybuy_months');
			return $customerOptions;
		} else {
			return $payment->getData('laybuy_'.strtolower($key));
		}
	}

	public function postToLaybuy($url = 'https://lay-buys.com/gateway/',$data = array()){	
		if(!is_array($data) || count($data) == 0) return false;
	
		$postdata ='';

		foreach($data as $lname=>$lvalue){
			/* if($lname == 'MEMBER') continue; */
			$postdata .= $lname."=".urlencode($lvalue)."&";
		}	
		$postdata = rtrim($postdata,'&');

		$ch = curl_init();					
		curl_setopt($ch, CURLOPT_URL,$url);	
		curl_setopt($ch, CURLOPT_POST, 1);					
		curl_setopt($ch, CURLOPT_POSTFIELDS, $postdata);					
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1); 					
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER,false);
		$result = curl_exec($ch);
	
		curl_close ($ch);
		
		$result = json_decode($result,true);
	
		if(isset($result['ACK']) && isset($result['TOKEN']) && $result['ACK'] == 'SUCCESS'){
			return $result['TOKEN'];
		}
		return false;				
	}
	
	public function fetchFromLaybuy($config){			
		$url = $config['hostname'];					
		$matchedData = $this->getMatchingData();
		/*$orderIds = *//* $this->getMatchingOrderIds() *//*$matchedData['orderIds']; */
		$profileIds = $matchedData['profileIds'];
		$data ='';					
		$data .= "mid=".$config['username']."&";					
		/* $data .= "custom=".$orderIds."&"; */
		$data .= "profileIds=".$profileIds;
		
		$ch = curl_init();					
		curl_setopt($ch, CURLOPT_URL,$url);	
		curl_setopt($ch, CURLOPT_POST, 1);					
		curl_setopt($ch, CURLOPT_POSTFIELDS, $data);					
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1); /* use this to suppress output */					
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER,false); /* tell cURL to graciously accept an SSL certificate */					
		$result = curl_exec ($ch);					
		curl_close ($ch);		
		 
		return json_decode($result);				
	}
	
	public function getMatchingOrderIds(){
		$result = '';
		$collection = $this->reportCollection->create()
							/* ->addFieldToFilter('last_payment_due',array('lt'=>date('Y-m-d h:i:s',time()))) */
							   ->addFieldToFilter('status',['eq'=>0]) ;
		foreach($collection as $report){
			$result .= $report->getData('laybuy_ref_no').",";
			/* $result .= $report->getData('order_id').","; */
		}
		return rtrim($result,',');
	}
	
	public function getMatchingData(){
		if($this->_matchingData != null) {
			return $this->_matchingData;
		}
		$result = array();
		$orderIds = '';
		$profileIds = '';
		$collection = $this->reportCollection->create()
							/* ->addFieldToFilter('last_payment_due',array('lt'=>date('Y-m-d h:i:s',time()))) */
							   ->addFieldToFilter('status',['eq'=>0]);
							   
		foreach($collection as $report){
			if($report->getData('laybuy_ref_no'))
				$orderIds .= $report->getData('laybuy_ref_no').",";
			if($report->getData('paypal_profile_id'))
				$profileIds .= $report->getData('paypal_profile_id').",";
			/* $result .= $report->getData('order_id').","; */
		}
		$result['orderIds'] = trim($orderIds,',');
		$result['profileIds'] = trim($profileIds,',');
		return $result;
	}
	
	public function cancelTransaction($report){
		$newStrReport = preg_replace('/Pending/i', 'Canceled', $report->getReport());
		try{
			if($this->cancelPaypalProfile($report->getPaypalProfileId(),$report->getStoreId())){
				if($this->processOrder($report->getOrderId(),0)){
					$report->setReport($newStrReport);
					$report->setStatus(-1);
					$report->save();
					return true;
				}else{
					return false;
				}
			}else{
				return false;
			}
		}catch(\Exception $e){
			return false;
		}
	}
	
	public function cancelPaypalProfile($paypalProfileId,$storeId){
		if(!$paypalProfileId)
			return true;

		$url = 'https://lay-buys.com/vtmob/deal5cancel.php';
		$data ='';			
		$data .= "&mid=".$this->scopeConfig->getValue('payment/laybuy/membership_number',\Magento\Store\Model\ScopeInterface::SCOPE_STORE,$storeId);
		$data .= "&paypal_profile_id=".$paypalProfileId;
		$ch = curl_init();		
		curl_setopt($ch, CURLOPT_URL,$url);	
		curl_setopt($ch, CURLOPT_POST, 1);		
		curl_setopt($ch, CURLOPT_POSTFIELDS, $data);		
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1); /* use this to suppress output */		
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER,false); /* tell cURL to graciously accept an SSL certificate */		
		$result = curl_exec ($ch);
		/* print_r($result);die; */
		if($result == 'success'){
			$result = print_r($result,true);
			curl_close ($ch);
			return true;
		}else{

			curl_close ($ch);
			return false;
		}
	}
	
	public function processOrder($orderIncrementId,$flag,$transactions = array() ,$profileId = ''){
		$order = $this->orderFactory->create()->loadByIncrementId($orderIncrementId);
		if ($order->getId()) {
			if(!$flag){
				if($order->canCancel()){
					$order->cancel()->save();

				}		
				return true;
			}
			if($flag==2){
				$payment_info = $order->getPayment()->getData('additional_information');
				$payment_info['transactions'][$profileId] = json_decode(json_encode($transactions),true);
				$order->getPayment()->setData('additional_information',$payment_info)->save();
				$order->save();
				
				return true;
			}
			try {
				if(!$order->canInvoice()){
				
					return false;
				}
				
				$invoice = $this->_invoiceService->prepareInvoice($order);
          						
				
				if (!$invoice->getTotalQty()) {
				
					return false;
				}
				$invoice->setRequestedCaptureCase(\Magento\Sales\Model\Order\Invoice::CAPTURE_ONLINE);
				$invoice->register();
				$invoice->save();
				$invoice->getOrder()->setIsInProcess(true);
				
				$transactionSave = $this->_transaction->addObject(
          								$invoice
          						)->addObject(
          								$invoice->getOrder()
          						);
          						$transactionSave->save();
				
				return true;
			}catch (\Exception $e) {
				return false;
			}
		}
		return false;
	}
	
	public function revisePlan($revise){
	
		$storeId = $revise->getStoreId();
		
		$url = 'https://lay-buys.com/vtmob/deal5.php';
		$data ='';		
		$data .= "eml=".$revise->getEmail();		
		$data .= "&prc=".$revise->getAmount();
		$data .= "&curr=".$revise->getCurrency();
		if($revise->getPaymentType()==1) {
			/* Lay-Buy Payment */
			$data .= "&pp=1";
			$data .= "&pplan=1";
		} else {
			/* Buy-Now Payment */
			$data .= "&pp=0";
			$data .= "&pplan=0";
		}
		$data .= "&init=".$revise->getDownpayment();
		$data .= "&mnth=".$revise->getMonths();
		$data .= "&mid=".$this->scopeConfig->getValue('payment/laybuy/membership_number',\Magento\Store\Model\ScopeInterface::SCOPE_STORE,$storeId);
		$data .= "&convrate=1";
		$data .= "&id=".$revise->getId()."-".$revise->getOrderId();
		$data .="&CANCELURL=".$this->url->getUrl('laybuy/revise/cancel/',['_secure'=>true]);
		$data .="&RETURNURL=".$this->url->getUrl('laybuy/revise/success/',['_secure'=>true]);
		$IMAGE  = $this->scopeConfig->getValue('payment/laybuy/image',\Magento\Store\Model\ScopeInterface::SCOPE_STORE,$storeId);
		if($IMAGE){
			$IMAGE = $this->_storeManager->getStore()->getBaseUrl(\Magento\Framework\UrlInterface::URL_TYPE_MEDIA)."laybuy/".$IMAGE;
		}else{
			$IMAGE = 'http://lay-buys.com/lb2.jpg';
		}
		$data .="&IMAGE=".$IMAGE;
		/* $arr = explode('&',$data);
		print_r($arr);die; */
		$ch = curl_init();		
		curl_setopt($ch, CURLOPT_URL,$url);
		curl_setopt($ch, CURLOPT_POST, 1);		
		curl_setopt($ch, CURLOPT_POSTFIELDS, $data);		
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1); /* use this to suppress output */		
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER,false); /* tell cURL to graciously accept an SSL certificate */		
		$result = curl_exec ($ch);
		
		if($result == 'success') {
			$result1 = $result;
			$result = print_r($result,true);
			curl_close ($ch);
			return $result1;
		} else {
			curl_close ($ch);
			return false;
		}
	}
	
	public function getPaidOrders() {
		$code = 'laybuy';
		$collection = $this->orderFactory->create()->getCollection();
		$collection->join(array('payment'=>'sales_order_payment'),'main_table.entity_id=parent_id && main_table.status = "processing"','method');
		$collection->join(array('order'=>'sales_order'),'payment.parent_id = order.entity_id','*');
		
		$collection->addFieldToFilter('method',$code);
		return $collection->getAllIds();
	}
	
	public function fetchBeforeRevise($profileId = 0) {
		if($profileId) {
			$this->_matchingData = ['orderIds'=>'','profileIds'=>$profileId];
			try {
				
				/* @var $reports Mage_laybuy_Model_Report_Instalment */
				$credentials = $this->laybuyReport->getApiCredentials();
				if (empty($credentials)) {
					return false;
				}
				foreach ($credentials as $config) {
					try {
						$fetched = $this->laybuyReport->fetchAndSave($config);
						if($fetched){
							return true;
						}else{
							return false;
						}
					} catch (\Exception $e) {
						return false;
					}
				}
			} catch (\Exception $e) {
				return false;
			} catch (\Exception $e) {
				return false;
			}
		}
		return false;
	}
 
     public function getStoreConfig($path){
         return $this->scopeConfig->getValue($path,\Magento\Store\Model\ScopeInterface::SCOPE_STORE);
     }   
 
    public function formatDate(
        $date = null,
        $format = \IntlDateFormatter::SHORT,
        $showTime = false,
        $timezone = null
    ) {
        $date = $date instanceof \DateTimeInterface ? $date : new \DateTime($date);
        return $this->_localeDate->formatDateTime(
            $date,
            $format,
            $showTime ? $format : \IntlDateFormatter::NONE,
            null,
            $timezone
        );
    }
    
    public function getLocaleCurrency(){
     return  $this->_currencyInterface;
    }
}