<?php
/**
 * CedCommerce
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the End User License Agreement (EULA)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://cedcommerce.com/license-agreement.txt
 *
 * @category    Ced
 * @package     Ced_LayBuy
 * @author      CedCommerce Core Team <connect@cedcommerce.com>
 * @copyright   Copyright CedCommerce (http://cedcommerce.com/)
 * @license     http://cedcommerce.com/license-agreement.txt
 */
namespace Ced\LayBuy\Model;

use Magento\Sales\Model\Order\Payment;
use Magento\Sales\Model\Order\Payment\Transaction;
use Magento\Directory\Helper\Data as DirectoryHelper;
class Standard extends \Magento\Payment\Model\Method\AbstractMethod
{
    protected $_code = 'laybuy';
    
    protected $_isInitializeNeeded = true;
    
	CONST LAYBUY = 'laybuy';
	
	/**
     * @var string
     */
    protected $_formBlockType = \Ced\LayBuy\Block\Form\Laybuy::class;

    /**
     * @var string
     */
    protected $_infoBlockType = \Ced\LayBuy\Block\Info\Laybuy::class;
	
	/**
	 * Payment Method feature
	 *
	 * @var bool
	 */
	public $_canUseInternal   = false;
	
    /**
    * @var \Ced\AxisBankPay\Helper\Security
    */
    public $security;

    /**
    * @var \Magento\Framework\UrlInterface
    */
    public $_urlBuilder;

    /**
    * @var \Magento\Store\Model\StoreManagerInterface
    */
    public $_storeManager;

    /**
     * 
     * @param \Magento\Framework\UrlInterface $urlBuilder
     * @param \Magento\Store\Model\StoreManagerInterface $storeManager
     * @param \Magento\Framework\Model\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param \Magento\Framework\Api\ExtensionAttributesFactory $extensionFactory
     * @param \Magento\Framework\Api\AttributeValueFactory $customAttributeFactory
     * @param \Magento\Payment\Helper\Data $paymentData
     * @param \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
     * @param \Magento\Payment\Model\Method\Logger $logger
     * @param \Ced\AxisBankPay\Helper\Security $security
     * @param \Magento\Framework\Model\ResourceModel\AbstractResource $resource
     * @param \Magento\Framework\Data\Collection\AbstractDb $resourceCollection
     * @param array $data
     */
    public function __construct(
      \Magento\Catalog\Model\ProductRepository $productRepository,
      \Magento\Framework\UrlInterface $urlBuilder,
      \Magento\Store\Model\StoreManagerInterface $storeManager,
      \Magento\Framework\Model\Context $context,
      \Magento\Framework\Registry $registry,
      \Magento\Framework\Api\ExtensionAttributesFactory $extensionFactory,
      \Magento\Framework\Api\AttributeValueFactory $customAttributeFactory,
      \Magento\Payment\Helper\Data $paymentData,
      \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
      \Magento\Payment\Model\Method\Logger $logger,
      array $data = [],
      DirectoryHelper $directory=null
    ) {
        
      $this->_urlBuilder = $urlBuilder;
      $this->_storeManager = $storeManager;
     $this->productRepository  = $productRepository;    
      parent::__construct(
          $context,
          $registry,
          $extensionFactory,
          $customAttributeFactory,
          $paymentData,
          $scopeConfig,
          $logger,
          null,
          null,
          $data,
          $directory
      );
     
    }

    public function isAvailable(\Magento\Quote\Api\Data\CartInterface $quote = null)
    {
        
        if ($status = parent::isAvailable($quote)) {
	
			$storeId = $quote ? $quote->getStoreId() : null;
			
			/* Condition for minimum checkout amount for method availability */
			$configTotal = $this->_scopeConfig->getValue('laybuy/conditional_criteria/total',\Magento\Store\Model\ScopeInterface::SCOPE_STORE,$storeId);
			$total = $quote ? $quote->getData('grand_total') : 0;
			if($total && $status && $configTotal){
				if($configTotal<$total){
					$status = true;
				}else{
					$status = false;
				}
			}
			
			/* Condition for customer groups for method availability */
			if($status){
				if($this->_scopeConfig->getValue('laybuy/conditional_criteria/allowspecificgroup',\Magento\Store\Model\ScopeInterface::SCOPE_STORE,$storeId)) {
					$configCustomerGroupId = explode(',',$this->_scopeConfig->getValue('laybuy/conditional_criteria/customergroup',\Magento\Store\Model\ScopeInterface::SCOPE_STORE,$storeId ));
					$customerGroupId = $quote ? $quote->getData('customer_group_id'):-5;
					if($customerGroupId != -5){
						if($configCustomerGroupId && in_array($customerGroupId,$configCustomerGroupId)){
							$status = true;
						}else{
							$status = false;
						}
					}
				}
			}	
			
			return $status;
		}
	}
	
	public function getOrderPlaceRedirectUrl()
	{
		//when you click on place order you will be redirected on this url, if you don't want this action remove this method
		return $this->_urlBuilder->getUrl('laybuy/standard/redirect', ['_secure' => true]);
	}
	
    public function validate(){
         
         parent::validate();
		 
		 /**
         * to validate payment method is allowed for billing country or not
         */
        $paymentInfo = $this->getInfoInstance();
        if ($paymentInfo instanceof Payment) {
           $cartItems = $paymentInfo->getOrder()->getAllItems();
			$storeId 	= $paymentInfo->getOrder()->getStoreId();
        } else {
            $cartItems = $paymentInfo->getQuote()->getAllItems();
			 $storeId 	= $paymentInfo->getQuote()->getStoreId();
        }

		 $flagArr = $this->canUseForCategories($cartItems, $storeId);
         if (!$flagArr[0]) {
             
             throw new \Magento\Framework\Exception\LocalizedException(
                __('Selected payment type is not allowed for '.$flagArr[1].' products.')
            );
         }
         return $this;
    }
    
    public function canUseForCategories($cartItems = [], $storeId=0)
    {
        /*
        for specific categories, the flag will set up as 1
        */
		$status = true;
		$productName = '';
		$configCategories = explode(',',$this->_scopeConfig->getValue('laybuy/conditional_criteria/categories',\Magento\Store\Model\ScopeInterface::SCOPE_STORE,$storeId ));
		$xproducts = explode(',',$this->_scopeConfig->getValue('laybuy/conditional_criteria/xproducts',\Magento\Store\Model\ScopeInterface::SCOPE_STORE,$storeId));
		
		foreach($cartItems as $_product){
			$_product = $this->productRepository->getById($_product->getProductId());
			if($xproducts && in_array($_product->getId(),$xproducts)){
				$status = false;
				$productName .= $_product->getName().',';
			} elseif(!$this->_scopeConfig->getValue('laybuy/conditional_criteria/allowspecificcategory',\Magento\Store\Model\ScopeInterface::SCOPE_STORE,$storeId)) {
				$status = true;
			} elseif ($configCategories && count(array_diff($_product->getCategoryIds(),$configCategories))>0){
				$status = false;
				$productName .= $_product->getName().',';
			}
		}
		$productName = rtrim($productName,',');
		
        return [$status,$productName];
    }
    
}