<?php
/**
 * CedCommerce
  *
  * NOTICE OF LICENSE
  *
  * This source file is subject to the End User License Agreement (EULA)
  * that is bundled with this package in the file LICENSE.txt.
  * It is also available through the world-wide-web at this URL:
  * http://cedcommerce.com/license-agreement.txt
  *
  * @category  Ced
  * @package   Ced_LayBuy
  * @author    CedCommerce Core Team <connect@cedcommerce.com >
  * @copyright Copyright CEDCOMMERCE (http://cedcommerce.com/)
  * @license   https://cedcommerce.com/license-agreement.txt
  */
namespace Ced\LayBuy\Model\System\Config\Backend;


use Magento\Framework\Exception\CouldNotSaveException;


class Cron extends \Magento\Framework\App\Config\Value
{
	const CRON_STRING_PATH = 'crontab/jobs/LayBuy_Automated_Fetch_Updates/schedule/cron_expr';
    const CRON_MODEL_PATH_INTERVAL = 'laybuy/fetch_reports/schedule';
    /**
     * @var Json
     */
    private $serializer;

    /**
     * Serialized constructor
     *
     * @param \Magento\Framework\Model\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param \Magento\Framework\App\Config\ScopeConfigInterface $config
     * @param \Magento\Framework\App\Cache\TypeListInterface $cacheTypeList
     * @param \Magento\Framework\Model\ResourceModel\AbstractResource|null $resource
     * @param \Magento\Framework\Data\Collection\AbstractDb|null $resourceCollection
     * @param array $data
     * @param Json|null $serializer
     */
    
    public function __construct(
        \Magento\Framework\Model\Context $context,
        \Magento\Framework\Registry $registry,
        \Magento\Framework\App\Config\ScopeConfigInterface $config,
        \Magento\Framework\App\Cache\TypeListInterface $cacheTypeList,
        \Magento\Framework\Model\ResourceModel\AbstractResource $resource = null,
        \Magento\Framework\Data\Collection\AbstractDb $resourceCollection = null,
    	\Magento\Framework\App\Config\ValueFactory $configfactory,	
        array $data = []
    ) {
    	$this->config = $configfactory;
        parent::__construct($context, $registry, $config, $cacheTypeList, $resource, $resourceCollection, $data);
    }

    

    /**
     * Cron settings after save
     * @return void
     */
    public function afterSave()
    {
        $cronExprString = '';
        $time = explode(',', $this->config->create()->load('laybuy/fetch_reports/time', 'path')->getValue());
        if ($this->config->create()->load('laybuy/fetch_reports/active', 'path')->getValue()) {
            $interval = $this->config->create()->load(self::CRON_MODEL_PATH_INTERVAL, 'path')->getValue();
            $cronExprString = $this->getSchedule($time,$interval);
        }
       
        $this->config->create()
            ->load(self::CRON_STRING_PATH, 'path')
            ->setValue($cronExprString)
            ->setPath(self::CRON_STRING_PATH)
            ->save();

        return parent::afterSave();
    }

	protected function getSchedule($time=array(),$interval)
     {
     	switch ($interval) {     		
     		case 2: return "{$time[1]} {$time[0]} */2 * *"; break;
     		case 7: return "{$time[1]} {$time[0]} * * 0"; break;
     		case 30: return "{$time[1]} {$time[0]} 1 * *"; break;
     		case 1: 
     		default : return "{$time[1]} {$time[0]} * * *"; break;
     	}
     }
}